//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Frame/Fit2DFrame.h
//! @brief     Defines class Fit2DFrame.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_FRAME_FIT2DFRAME_H
#define BORNAGAIN_GUI_VIEW_FRAME_FIT2DFRAME_H

#include <QAction>
#include <QWidget>

class AxesPanel;
class ColorMapCanvas;
class DataSource;
class JobItem;
class PlotStatusLabel;
class ProgressCanvas;

//! Plots realdata, simulated data and relative difference map during the course of the fit.

class Fit2DFrame : public QWidget {
    Q_OBJECT
public:
    explicit Fit2DFrame(JobItem* item);
    ~Fit2DFrame();

private:
    void onResetViewAction();
    void connectItems();
    void updateDiffData();

    ColorMapCanvas* m_real_canvas;
    ColorMapCanvas* m_simu_canvas;
    ColorMapCanvas* m_diff_canvas;
    ProgressCanvas* m_progress_canvas;
    PlotStatusLabel* m_status_label;
    AxesPanel* m_axes_panel;

    QAction* m_reset_view_action;
    std::unique_ptr<DataSource> m_data_source;
};

#endif // BORNAGAIN_GUI_VIEW_FRAME_FIT2DFRAME_H
